**********
Quickstart
**********

这里是一个使用 ISEK 创建一个简单聊天代理的基本示例：

.. literalinclude:: ../../examples/single_agent_chat.py
   :language: python
   :caption: examples/single_agent_chat.py
   :linenos:

要运行这个例子... [提供运行指令]